@@ -1,4 +1,6 @@
 "Main interface for iot-data service type defs"
+from __future__ import annotations
+
 import sys
 from typing import IO, Union
 
@@ -8,6 +10,12 @@ else:
     from typing_extensions import TypedDict
 
 
+__all__ = (
+    "DeleteThingShadowResponseTypeDef",
+    "GetThingShadowResponseTypeDef",
+    "UpdateThingShadowResponseTypeDef",
+)
+
 DeleteThingShadowResponseTypeDef = TypedDict(
     "DeleteThingShadowResponseTypeDef", {"payload": Union[bytes, IO]}
 )
